==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/plugins/orf_marker/src/ORFWorker.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_ORF_WORKER_H_
#define _GB2_ORF_WORKER_H_

#include <workflow_library/LocalDomain.h>
#include <workflow_support/WorkflowUtils.h>
#include <util_algorithm/ORFFinder.h>

namespace GB2 {

namespace LocalWorkflow {

class ORFPrompter;
typedef PrompterBase<ORFPrompter> ORFPrompterBase;

class ORFPrompter : public ORFPrompterBase {
    Q_OBJECT
public:
    ORFPrompter(Actor* p = 0) : ORFPrompterBase(p) {}
protected:
    QString composeRichDoc();
};

class ORFWorker : public BaseWorker {
    Q_OBJECT
public:
    ORFWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL) {}
    virtual void init() ;
    virtual bool isReady();
    virtual Task* tick() ;
    virtual bool isDone() ;
    virtual void cleanup() {}
private slots:
    void sl_taskFinished();

protected:
    CommunicationChannel *input, *output;
    QString resultName,transId;
    ORFAlgorithmSettings cfg;
}; 

class ORFWorkerFactory : public DomainFactory {
public:
    static const QString ACTOR_ID;
    static void init();
    ORFWorkerFactory() : DomainFactory(ACTOR_ID) {}
    virtual Worker* createWorker(Actor* a) {return new ORFWorker(a);}
};

}//Workflow namespace
}//GB2 namespace

#endif

==> ugene_1.7.1+repack.orig.tar.gz: ugene-1.7.1/src/plugins/orf_marker/src/ORFWorker.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_ORF_WORKER_H_
#define _GB2_ORF_WORKER_H_

#include <workflow_library/LocalDomain.h>
#include <workflow_support/WorkflowUtils.h>
#include <util_algorithm/ORFFinder.h>

namespace GB2 {

namespace LocalWorkflow {

class ORFPrompter;
typedef PrompterBase<ORFPrompter> ORFPrompterBase;

class ORFPrompter : public ORFPrompterBase {
    Q_OBJECT
public:
    ORFPrompter(Actor* p = 0) : ORFPrompterBase(p) {}
protected:
    QString composeRichDoc();
};

class ORFWorker : public BaseWorker {
    Q_OBJECT
public:
    ORFWorker(Actor* a);
    
    virtual void init();
    virtual bool isReady();
    virtual Task* tick();
    virtual bool isDone();
    virtual void cleanup();
    
private slots:
    void sl_taskFinished();

protected:
    CommunicationChannel *input, *output;
    QString resultName,transId;
    ORFAlgorithmSettings cfg;
    
}; 

class ORFWorkerFactory : public DomainFactory {
public:
    static const QString ACTOR_ID;
    static void init();
    ORFWorkerFactory() : DomainFactory(ACTOR_ID) {}
    virtual Worker* createWorker(Actor* a) {return new ORFWorker(a);}
};

}//Workflow namespace
}//GB2 namespace

#endif
